==> kubernetes-model-core-5.7.4-sources.jar: io/fabric8/kubernetes/api/model/ConfigMapKeySelectorBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ConfigMapKeySelectorBuilder extends io.fabric8.kubernetes.api.model.ConfigMapKeySelectorFluentImpl<io.fabric8.kubernetes.api.model.ConfigMapKeySelectorBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.ConfigMapKeySelector,io.fabric8.kubernetes.api.model.ConfigMapKeySelectorBuilder>{
  public ConfigMapKeySelectorBuilder() {
    this(false);
  }
  public ConfigMapKeySelectorBuilder(java.lang.Boolean validationEnabled) {
    this(new ConfigMapKeySelector(), validationEnabled);
  }
  public ConfigMapKeySelectorBuilder(io.fabric8.kubernetes.api.model.ConfigMapKeySelectorFluent<?> fluent) {
    this(fluent, false);
  }
  public ConfigMapKeySelectorBuilder(io.fabric8.kubernetes.api.model.ConfigMapKeySelectorFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ConfigMapKeySelector(), validationEnabled);
  }
  public ConfigMapKeySelectorBuilder(io.fabric8.kubernetes.api.model.ConfigMapKeySelectorFluent<?> fluent,io.fabric8.kubernetes.api.model.ConfigMapKeySelector instance) {
    this(fluent, instance, false);
  }
  public ConfigMapKeySelectorBuilder(io.fabric8.kubernetes.api.model.ConfigMapKeySelectorFluent<?> fluent,io.fabric8.kubernetes.api.model.ConfigMapKeySelector instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withKey(instance.getKey()); 
    fluent.withName(instance.getName()); 
    fluent.withOptional(instance.getOptional()); 
    this.validationEnabled = validationEnabled; 
  }
  public ConfigMapKeySelectorBuilder(io.fabric8.kubernetes.api.model.ConfigMapKeySelector instance) {
    this(instance,false);
  }
  public ConfigMapKeySelectorBuilder(io.fabric8.kubernetes.api.model.ConfigMapKeySelector instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withKey(instance.getKey()); 
    this.withName(instance.getName()); 
    this.withOptional(instance.getOptional()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.ConfigMapKeySelectorFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.ConfigMapKeySelector build() {
    ConfigMapKeySelector buildable = new ConfigMapKeySelector(fluent.getKey(),fluent.getName(),fluent.getOptional());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ConfigMapKeySelectorBuilder that = (ConfigMapKeySelectorBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-core-5.12.0-sources.jar: io/fabric8/kubernetes/api/model/ConfigMapKeySelectorBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ConfigMapKeySelectorBuilder extends io.fabric8.kubernetes.api.model.ConfigMapKeySelectorFluentImpl<io.fabric8.kubernetes.api.model.ConfigMapKeySelectorBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.ConfigMapKeySelector,io.fabric8.kubernetes.api.model.ConfigMapKeySelectorBuilder>{
  public ConfigMapKeySelectorBuilder() {
    this(false);
  }
  public ConfigMapKeySelectorBuilder(java.lang.Boolean validationEnabled) {
    this(new ConfigMapKeySelector(), validationEnabled);
  }
  public ConfigMapKeySelectorBuilder(io.fabric8.kubernetes.api.model.ConfigMapKeySelectorFluent<?> fluent) {
    this(fluent, false);
  }
  public ConfigMapKeySelectorBuilder(io.fabric8.kubernetes.api.model.ConfigMapKeySelectorFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ConfigMapKeySelector(), validationEnabled);
  }
  public ConfigMapKeySelectorBuilder(io.fabric8.kubernetes.api.model.ConfigMapKeySelectorFluent<?> fluent,io.fabric8.kubernetes.api.model.ConfigMapKeySelector instance) {
    this(fluent, instance, false);
  }
  public ConfigMapKeySelectorBuilder(io.fabric8.kubernetes.api.model.ConfigMapKeySelectorFluent<?> fluent,io.fabric8.kubernetes.api.model.ConfigMapKeySelector instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withKey(instance.getKey()); 
    fluent.withName(instance.getName()); 
    fluent.withOptional(instance.getOptional()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ConfigMapKeySelectorBuilder(io.fabric8.kubernetes.api.model.ConfigMapKeySelector instance) {
    this(instance,false);
  }
  public ConfigMapKeySelectorBuilder(io.fabric8.kubernetes.api.model.ConfigMapKeySelector instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withKey(instance.getKey()); 
    this.withName(instance.getName()); 
    this.withOptional(instance.getOptional()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.ConfigMapKeySelectorFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.ConfigMapKeySelector build() {
    ConfigMapKeySelector buildable = new ConfigMapKeySelector(fluent.getKey(),fluent.getName(),fluent.getOptional());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ConfigMapKeySelectorBuilder that = (ConfigMapKeySelectorBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
